@@ -1,9 +1,10 @@
 package Devel::CStacktrace;
-$Devel::CStacktrace::VERSION = '0.006';
+$Devel::CStacktrace::VERSION = '0.007';
 use strict;
 use warnings;
 use Devel::cst ();
-use Sub::Exporter::Progressive -setup => { exports => [qw/stacktrace/] };
+use Exporter 5.57 'import';
+our @EXPORT_OK = 'stacktrace';
 
 1;
 
@@ -21,10 +22,12 @@ Devel::CStacktrace - C stacktraces for GNU systems
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
+ use Devel::CStacktrace 'stacktrace';
+
  say for stacktrace(128);
 
 =head1 DESCRIPTION
